<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>FontsDialog</name>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="28"/>
        <source>LabelsFont</source>
        <translation>Labels</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="31"/>
        <location filename="../../src/FontsDialog.cpp" line="51"/>
        <source>ResetDefaultValue</source>
        <translation>Reset</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="48"/>
        <source>FieldsFont</source>
        <translation>Fields</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="63"/>
        <source>LanguageFontOverrides</source>
        <translation>Language Font Overrides</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="73"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="75"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="89"/>
        <source>Fonts Settings</source>
        <translation>Fonts Settings</translation>
    </message>
</context>
<context>
    <name>HelpBrowser</name>
    <message>
        <location filename="../../src/HelpBrowser.cpp" line="8"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../../src/HelpBrowser.cpp" line="9"/>
        <source>Back</source>
        <translation>Back</translation>
    </message>
    <message>
        <location filename="../../src/HelpBrowser.cpp" line="30"/>
        <source>Help: %1</source>
        <translation>Help: %1</translation>
    </message>
</context>
<context>
    <name>KeyboardAcceleratorsDialog</name>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="23"/>
        <source>Action</source>
        <translation>Action</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="23"/>
        <source>Key</source>
        <translation>Key</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="43"/>
        <source>Clear key</source>
        <translation>Clear Key</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="44"/>
        <source>Set key</source>
        <translation>Set Key</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="45"/>
        <source>Reset key</source>
        <translation>Reset Key</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="63"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="65"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="87"/>
        <source>Keyboard Accelerator Definitions</source>
        <translation>Keyboard Accelerators</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="122"/>
        <source>&lt;press key&gt;</source>
        <translation>&lt;Press Key&gt;</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="190"/>
        <source>Duplicate key binding</source>
        <translation>Duplicate Key Binding</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="191"/>
        <source>Key &apos;</source>
        <translation>Key &apos;</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="191"/>
        <source>&apos;
is currently assigned to
&apos;</source>
        <translation>&apos;
is currently assigned to
&apos;</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="192"/>
        <source>&apos;.
Overwrite the current assignment?</source>
        <translation>&apos;. Overwrite the current assignment?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/MainWindow.cpp" line="60"/>
        <location filename="../../src/MainWindow.cpp" line="176"/>
        <location filename="../../src/MainWindow.cpp" line="217"/>
        <source>StartQuiz</source>
        <translation>Start Quiz</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="62"/>
        <location filename="../../src/MainWindow.cpp" line="218"/>
        <source>ManageGlossaries</source>
        <translation>Manage Glossaries</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="64"/>
        <location filename="../../src/MainWindow.cpp" line="219"/>
        <source>Import...</source>
        <translation>Import Data</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="66"/>
        <location filename="../../src/MainWindow.cpp" line="220"/>
        <source>Export...</source>
        <translation>Export Data</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="70"/>
        <location filename="../../src/MainWindow.cpp" line="222"/>
        <source>Preferences...</source>
        <translation>Preferences</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="72"/>
        <location filename="../../src/MainWindow.cpp" line="223"/>
        <source>Quit</source>
        <translation>Quit</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="132"/>
        <location filename="../../src/MainWindow.cpp" line="236"/>
        <source>About...</source>
        <translation>About toMOTko</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="176"/>
        <source>RestartQuiz</source>
        <translation>Restart Quiz</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="68"/>
        <location filename="../../src/MainWindow.cpp" line="221"/>
        <source>ShowAllGlossariesAndTerms</source>
        <translation>Show All Glossaries and Terms</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="275"/>
        <source>AboutToMOTko...</source>
        <translation>About toMOTko...</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="275"/>
        <source>AboutMessage</source>
        <translation>&lt;html&gt;&lt;h2&gt;toMOTko v0.11.2&lt;/h2&gt;&lt;p&gt;Small application to learn new vocabulary.&lt;/p&gt;&lt;p&gt;Written by Frederic Bergeron&lt;br/&gt;(&lt;a href=&quot;mailto:fbergeron@users.sourceforge.net&quot;&gt;fbergeron@users.sourceforge.net&lt;/a&gt;)&lt;br/&gt;Copyright (c) 2006-2010&lt;/p&gt;&lt;p&gt;This program is GPL v2.&lt;/p&gt;&lt;p&gt;Homepage: &lt;a href=&quot;http://tomotko.sourceforge.net&quot;&gt;http://tomotko.sourceforge.net&lt;/a&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="52"/>
        <location filename="../../src/MainWindow.cpp" line="213"/>
        <source>Reveal</source>
        <translation>Reveal</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="54"/>
        <location filename="../../src/MainWindow.cpp" line="214"/>
        <source>RightAnswer</source>
        <translation>Right Answer</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="56"/>
        <location filename="../../src/MainWindow.cpp" line="215"/>
        <source>WrongAnswer</source>
        <translation>Wrong Answer</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="58"/>
        <location filename="../../src/MainWindow.cpp" line="216"/>
        <source>EditQuizTerm</source>
        <translation>Edit Quiz Term</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="74"/>
        <location filename="../../src/MainWindow.cpp" line="224"/>
        <source>AddFolder</source>
        <translation>Add Folder</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="76"/>
        <location filename="../../src/MainWindow.cpp" line="225"/>
        <source>AddGlossary</source>
        <translation>Add Glossary</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="78"/>
        <location filename="../../src/MainWindow.cpp" line="226"/>
        <source>RemoveItem</source>
        <translation>Remove Item</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="80"/>
        <location filename="../../src/MainWindow.cpp" line="227"/>
        <source>AddTerm</source>
        <translation>Add Word</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="82"/>
        <location filename="../../src/MainWindow.cpp" line="228"/>
        <source>EditTerm</source>
        <translation>Edit Word</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="84"/>
        <location filename="../../src/MainWindow.cpp" line="229"/>
        <source>RemoveTerm</source>
        <translation>Remove Word(s)</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="86"/>
        <location filename="../../src/MainWindow.cpp" line="230"/>
        <source>CheckAllTerms</source>
        <translation>Check All Words</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="88"/>
        <location filename="../../src/MainWindow.cpp" line="231"/>
        <source>InverseCheckedTerms</source>
        <translation>Inverse Checked Words</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="90"/>
        <location filename="../../src/MainWindow.cpp" line="232"/>
        <source>Maximize</source>
        <translation>Maximize</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="298"/>
        <source>ConfirmResumeQuiz</source>
        <translation>There is a resumable quiz available for the current languages. Do you want to resume this quiz?</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="304"/>
        <source>Yes</source>
        <translation>Yes</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="305"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="317"/>
        <source>NoTermsMarkedForStudy</source>
        <translation>No terms have been marked for study for the specified languages. The quiz cannot start. Use the Glossary Manager to select the terms you want to study.</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="322"/>
        <source>TermsMissing</source>
        <translation>The terms that were in this quiz cannot be found.  The quiz cannot be resumed.</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="92"/>
        <location filename="../../src/MainWindow.cpp" line="233"/>
        <source>Search...</source>
        <translation>Search</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="130"/>
        <location filename="../../src/MainWindow.cpp" line="235"/>
        <source>Help...</source>
        <translation>Help</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="73"/>
        <source>DigraphesEnabled</source>
        <translation>Digraphs Enabled</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="34"/>
        <source>Length</source>
        <translation>Quiz Length
(Repetitions)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="54"/>
        <source>QuizLengthShortest</source>
        <translation>Shortest (1)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="55"/>
        <source>QuizLengthMedium</source>
        <translation>Medium (3)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="57"/>
        <source>QuizLengthLongest</source>
        <translation>Longest (5)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="87"/>
        <source>InterfaceLanguage</source>
        <translation>Interface Language</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="143"/>
        <source>Revealing Sequences Settings</source>
        <translation>Revealing Sequences...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="189"/>
        <source>Preferences...</source>
        <translation>Preferences</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="134"/>
        <source>Keyboard Accelerator Definitions</source>
        <translation>Keyboard Accelerators...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="76"/>
        <source>hideQuizButtons</source>
        <translation>Hide Quiz Buttons</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="79"/>
        <source>ShowAltInTermList</source>
        <translation>Show Alt./Phon. Value</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="137"/>
        <source>Study Language Definitions</source>
        <translation>Study Languages...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="140"/>
        <source>Fonts Settings</source>
        <translation>Fonts...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="151"/>
        <source>Ok</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="153"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PropertiesPanel</name>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="59"/>
        <location filename="../../src/PropertiesPanel.cpp" line="92"/>
        <source>Words</source>
        <translation>Words</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="99"/>
        <source>Glossaries</source>
        <translation>Glossaries</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="106"/>
        <source>Folders</source>
        <translation>Folders</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="127"/>
        <location filename="../../src/PropertiesPanel.cpp" line="284"/>
        <source>Title</source>
        <translation>Title</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="133"/>
        <location filename="../../src/PropertiesPanel.cpp" line="279"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="137"/>
        <location filename="../../src/PropertiesPanel.cpp" line="280"/>
        <source>Content</source>
        <translation>Content</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Items</source>
        <translation>Items</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Selected</source>
        <translation>Quiz</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Checked</source>
        <translation>Checked</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="169"/>
        <location filename="../../src/PropertiesPanel.cpp" line="285"/>
        <source>Author</source>
        <translation>Author</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="175"/>
        <location filename="../../src/PropertiesPanel.cpp" line="286"/>
        <source>CreationDate</source>
        <translation>Creation</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="181"/>
        <location filename="../../src/PropertiesPanel.cpp" line="287"/>
        <source>ModificationDate</source>
        <translation>Modification</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>ar</source>
        <translation>Arabic</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>bg</source>
        <translation>Bulgarian</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>el</source>
        <translation>Greek</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>cs</source>
        <translation>Czech</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>da</source>
        <translation>Danish</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>it</source>
        <translation>Italian</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>eo</source>
        <translation>Esperanto</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>fi</source>
        <translation>Finnish</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>he</source>
        <translation>Hebrew</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>hi</source>
        <translation>Hindi</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>hu</source>
        <translation>Hungarian</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>ko</source>
        <translation>Korean</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>nl</source>
        <translation>Dutch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>pt</source>
        <translation>Portuguese</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>la</source>
        <translation>Latin</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>no</source>
        <translation>Norwegian</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>rm</source>
        <translation>Romansh</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>ru</source>
        <translation>Russian</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>sw</source>
        <translation>Swahili</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>th</source>
        <translation>Thai</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>ro</source>
        <translation>Romanian</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>sv</source>
        <translation>Swedish</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="9"/>
        <source>vi</source>
        <translation>Vietnamese</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="9"/>
        <source>zh</source>
        <translation>Chinese</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="9"/>
        <source>tl</source>
        <translation>Tagalog</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>en</source>
        <translation>English</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>fr</source>
        <translation>French</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>es</source>
        <translation>Spanish</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>ja</source>
        <translation>Japanese</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>de</source>
        <translation>German</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="40"/>
        <source>Cut</source>
        <translation>Cut</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="39"/>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="41"/>
        <source>Paste</source>
        <translation>Paste</translation>
    </message>
    <message>
        <location filename="../../src/ResultListItem.cpp" line="20"/>
        <location filename="../../src/ResultListItem.cpp" line="33"/>
        <location filename="../../src/TermListItem.cpp" line="23"/>
        <location filename="../../src/TermListItem.cpp" line="36"/>
        <source>Undefined</source>
        <translation>Undefined</translation>
    </message>
    <message>
        <location filename="../../src/FolderParser.cpp" line="46"/>
        <location filename="../../src/MainWindow.cpp" line="270"/>
        <location filename="../../src/TermDialog.cpp" line="246"/>
        <location filename="../../src/VocabParser.cpp" line="85"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="270"/>
        <source>ErrorSavingData</source>
        <translation>A problem occurred when saving data.  Check file permissions and disk space.</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="288"/>
        <location filename="../../src/SequenceDialog.cpp" line="200"/>
        <location filename="../../src/SequenceDialog.cpp" line="206"/>
        <location filename="../../src/SequencesDialog.cpp" line="85"/>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="87"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="833"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="967"/>
        <source>Warning</source>
        <translation>Warning</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="298"/>
        <location filename="../../src/MainWindow.cpp" line="317"/>
        <location filename="../../src/MainWindow.cpp" line="322"/>
        <location filename="../../src/QuizFrame.cpp" line="387"/>
        <location filename="../../src/QuizFrame.cpp" line="757"/>
        <location filename="../../src/QuizFrame.cpp" line="763"/>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="408"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="458"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="484"/>
        <source>OperationSuccessful</source>
        <translation>Operation Successful</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="416"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="419"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="460"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="486"/>
        <source>OperationFailed</source>
        <translation>Operation Failed</translation>
    </message>
    <message>
        <location filename="../../src/FolderParser.cpp" line="47"/>
        <location filename="../../src/VocabParser.cpp" line="86"/>
        <source>ParseError</source>
        <translation>Parse error at line %1, col %2. %3.</translation>
    </message>
    <message>
        <location filename="../../src/Controller.cpp" line="737"/>
        <source>MyGlossaries</source>
        <translation>My Glossaries</translation>
    </message>
    <message>
        <location filename="../../src/Controller.cpp" line="144"/>
        <source>NewFolder</source>
        <translation>New Folder</translation>
    </message>
    <message>
        <location filename="../../src/Controller.cpp" line="173"/>
        <source>NewGlossary</source>
        <translation>New Glossary</translation>
    </message>
</context>
<context>
    <name>QuizFrame</name>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="104"/>
        <location filename="../../src/QuizFrame.cpp" line="139"/>
        <location filename="../../src/QuizFrame.cpp" line="149"/>
        <location filename="../../src/QuizFrame.cpp" line="187"/>
        <location filename="../../src/QuizFrame.cpp" line="202"/>
        <location filename="../../src/QuizFrame.cpp" line="636"/>
        <location filename="../../src/QuizFrame.cpp" line="639"/>
        <location filename="../../src/QuizFrame.cpp" line="640"/>
        <location filename="../../src/QuizFrame.cpp" line="643"/>
        <source>???</source>
        <translation>???</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="387"/>
        <source>WellDone</source>
        <translation>Well done.  You&apos;ve learned all the %1 selected words. Pick other words in the Glossary Manager and start another quiz to learn more vocabulary.</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="757"/>
        <location filename="../../src/QuizFrame.cpp" line="763"/>
        <source>DissociatedWord</source>
        <translation>The word has been dissociated from its original glossary.  Edition cannot be performed from the Quiz.</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="99"/>
        <location filename="../../src/QuizFrame.cpp" line="128"/>
        <location filename="../../src/QuizFrame.cpp" line="635"/>
        <location filename="../../src/QuizFrame.cpp" line="638"/>
        <source>Word/Expr.</source>
        <translation>Word/Expr.</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="126"/>
        <location filename="../../src/QuizFrame.cpp" line="637"/>
        <source>Alt./Phon.</source>
        <translation>Alt./Phon.</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="169"/>
        <location filename="../../src/QuizFrame.cpp" line="642"/>
        <source>Examples/Comments</source>
        <translation>Examples/Comments</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="197"/>
        <location filename="../../src/QuizFrame.cpp" line="641"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="47"/>
        <location filename="../../src/SearchDialog.cpp" line="169"/>
        <source>Results</source>
        <translation>Results</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="61"/>
        <location filename="../../src/SearchDialog.cpp" line="174"/>
        <source>Glossary</source>
        <translation>Glossary</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="61"/>
        <location filename="../../src/SearchDialog.cpp" line="174"/>
        <source>Location</source>
        <translation>Location</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="72"/>
        <location filename="../../src/SearchDialog.cpp" line="176"/>
        <source>View Glossary</source>
        <translation>View Glossary</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="113"/>
        <location filename="../../src/SearchDialog.cpp" line="187"/>
        <source>Search...</source>
        <translation>Search...</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="77"/>
        <location filename="../../src/SearchDialog.cpp" line="178"/>
        <source>Edit Term</source>
        <translation>Edit</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="82"/>
        <location filename="../../src/SearchDialog.cpp" line="180"/>
        <source>Remove Term(s)</source>
        <translation>Remove</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="88"/>
        <location filename="../../src/SearchDialog.cpp" line="182"/>
        <source>Close</source>
        <translation>Close</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="170"/>
        <location filename="../../src/SearchDialog.cpp" line="208"/>
        <source>%1 term(s) found</source>
        <translation>%1 Word(s) Found</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="288"/>
        <source>ConfirmRemoveSelectedTerms</source>
        <translation>Are you sure that you want to remove the selected word(s)?</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="294"/>
        <source>Yes</source>
        <translation>Yes</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="295"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="336"/>
        <source>MultipleTranslationsDetectedForRemoveTermsCaption</source>
        <translation>Remove Words</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="336"/>
        <source>MultipleTranslationsDetectedForRemoveTerms</source>
        <translation>Some of the selected words contain translations in many languages.  Please indicate which translations to delete.</translation>
    </message>
</context>
<context>
    <name>SequenceDialog</name>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="22"/>
        <source>Quiz</source>
        <translation>Quiz Window</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="52"/>
        <source>FirstLanguage</source>
        <translation>First Language</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="56"/>
        <location filename="../../src/SequenceDialog.cpp" line="88"/>
        <source>Word/Expr.</source>
        <translation>Word/Expr.</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="72"/>
        <source>TestLanguage</source>
        <translation>Test Language</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="86"/>
        <source>Alt./Phon.</source>
        <translation>Alt./Phon.</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="102"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="115"/>
        <source>CommentLabelPanel</source>
        <translation>Examples/Comments</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="128"/>
        <source>Sequence</source>
        <translation>Sequence</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="191"/>
        <source>AddRevealingSequence</source>
        <translation>Add Revealing Sequence...</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="200"/>
        <source>SequenceIsEmpty</source>
        <translation>The currently edited revealing sequence is empty.  If you want want to discard it, click Cancel to close the dialog.</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="206"/>
        <source>SequenceNotTerminated</source>
        <translation>The currently edited revealing sequence doesn&apos;t end by a revealable item.  This is invalid.  Remove the last operator or add another revealable item.</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="166"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="168"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
</context>
<context>
    <name>SequencesDialog</name>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="23"/>
        <source>Existing Sequences</source>
        <translation>Existing Sequences</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="47"/>
        <source>QuizWindow</source>
        <translation>Quiz Window</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="62"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="64"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="78"/>
        <source>RevealingOrders</source>
        <translation>Revealing Sequences</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="85"/>
        <source>RevealingOrderMandatory</source>
        <translation>You must select at least one revealing sequence option. If none are available, create a new one.</translation>
    </message>
</context>
<context>
    <name>StudyLanguagesDialog</name>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="26"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="28"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="45"/>
        <source>Study Language Definitions</source>
        <translation>Study Languages</translation>
    </message>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="87"/>
        <source>StudyLanguagesMandatory</source>
        <translation>You must select at least two study languages
(one for the source language and another one for the target language.)</translation>
    </message>
</context>
<context>
    <name>TermDialog</name>
    <message>
        <location filename="../../src/TermDialog.cpp" line="62"/>
        <location filename="../../src/TermDialog.cpp" line="84"/>
        <source>Word/Expr.</source>
        <translation>Word/Expr.</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="82"/>
        <source>Alt./Phon.</source>
        <translation>Alt./Phon.</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="109"/>
        <source>Examples/Comments</source>
        <translation>Examples/Comments</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="167"/>
        <source>EditTerm</source>
        <translation>Edit Word</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="137"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="128"/>
        <source>setImage</source>
        <translation>Set</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="132"/>
        <source>clearImage</source>
        <translation>Clear</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="214"/>
        <source>SetImage...</source>
        <translation>Set Image...</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="148"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="150"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="214"/>
        <source>Images (*.png *.gif)</source>
        <translation>Images (*.png *.gif)</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="246"/>
        <source>CannotReadImage</source>
        <translation>The image cannot be read successfully.</translation>
    </message>
</context>
<context>
    <name>TranslationSelectionDialog</name>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="15"/>
        <source>Languages</source>
        <translation>Languages</translation>
    </message>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="37"/>
        <source>CheckAllLanguages</source>
        <translation>Check All Languages</translation>
    </message>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="45"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="47"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
</context>
<context>
    <name>Util</name>
    <message>
        <location filename="../../src/Util.cpp" line="22"/>
        <source>VerySmall</source>
        <translation>Very small</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="23"/>
        <source>Small</source>
        <translation>Small</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="24"/>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="25"/>
        <source>Large</source>
        <translation>Large</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="26"/>
        <source>VeryLarge</source>
        <translation>Very large</translation>
    </message>
</context>
<context>
    <name>VocabularyManagerFrame</name>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="1015"/>
        <source>MultipleTranslationsDetectedForRemoveTermsCaption</source>
        <translation>Remove Words</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="1015"/>
        <source>MultipleTranslationsDetectedForRemoveTerms</source>
        <translation>Some of the selected words contain translations in many languages.  Please indicate which translations to delete.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="361"/>
        <source>MultipleTranslationsDetectedForImport</source>
        <translation>The data you want to import contains words translated in many languages.  Please indicate which translations to import.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="442"/>
        <source>MultipleTranslationsDetectedForExport</source>
        <translation>The glossary contains words translated in many languages.  Please indicate which translations to export.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="839"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="973"/>
        <source>Yes</source>
        <translation>Yes</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="840"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="974"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="46"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="596"/>
        <source>Glossaries</source>
        <translation>Glossaries</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="458"/>
        <source>GlossaryExportSuccessful</source>
        <translation>The glossary has been exported successfully.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="416"/>
        <source>ItemImportFailed</source>
        <translation>An error has occurred.  The data has not been imported.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="419"/>
        <source>ItemImportFailedZipFileExpected</source>
        <translation>Wrong file format.  Zip file expected. The data has not been imported.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="460"/>
        <source>GlossaryExportFailed</source>
        <translation>An error has occurred.  The glossary has not been exported.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="833"/>
        <source>ConfirmRemoveItem</source>
        <translation>Are you sure that you want to remove this item?</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="967"/>
        <source>ConfirmRemoveSelectedTerms</source>
        <translation>Are you sure that you want to remove the selected word(s)?</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="186"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="604"/>
        <source>Properties</source>
        <translation>Properties</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="187"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="605"/>
        <source>Words</source>
        <translation>Words</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="468"/>
        <source>MultipleTranslationsDetectedForFolderExport</source>
        <translation>The folder contains words translated in many languages.  Please indicate which translations to export.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="484"/>
        <source>FolderExportSuccessful</source>
        <translation>The folder has been exported successfully.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="486"/>
        <source>FolderExportFailed</source>
        <translation>An error has occurred.  The folder has not been exported.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="353"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="361"/>
        <source>Import...</source>
        <translation>Import...</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="405"/>
        <source>ImportSuccessful</source>
        <translation>The data has been imported successfully.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="407"/>
        <source>InvisibleImport</source>
        <translation>

The new data are not visible for now. To view the new data, you must select appropriate languages in the language selectors.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="442"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="453"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="468"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="479"/>
        <source>Export...</source>
        <translation>Export...</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="353"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="454"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="480"/>
        <source>Glossaries (*.zip)</source>
        <translation>Glossaries (*.zip)</translation>
    </message>
</context>
</TS>
